@@ -2,10 +2,17 @@
 Combine all the mixins into full fledge classes
 """
 
+from xml.etree.ElementTree import Element
+
 from ..utils.safe_json import SafeJSON
 from .condition_mixin import FieldConditionMixin
 from .https import HTTPSRateCapedLookup
-from .multiple_mixin import DATQueryMixin, DTQueryMixin, TitleAuthorQueryMixin
+from .multiple_mixin import (
+    DATQueryMixin,
+    DTQueryMixin,
+    TitleAuthorQueryMixin,
+    TitleQueryMixin,
+)
 from .search_mixin import EntryMatchSearchMixin
 
 
@@ -34,3 +41,12 @@ class JSON_AT_Lookup(
     HTTPSRateCapedLookup,
 ):
     pass
+
+
+class XML_T_Lookup(
+    FieldConditionMixin,
+    TitleQueryMixin,
+    EntryMatchSearchMixin[Element],
+    HTTPSRateCapedLookup,
+):
+    pass
