@@ -12,10 +12,10 @@ LICENSE = "MIT"
 DESCRIPTION = "Module to complete bibtex files by polling online databases"
 
 VERSION_MAJOR = 1
-VERSION_MINOR = 0
-VERSION_PATCH = 5
+VERSION_MINOR = 1
+VERSION_PATCH = 0
 
-VERSION_DATE = "2022-04-13"
+VERSION_DATE = "2022-05-21"
 
 VERSION = (VERSION_MAJOR, VERSION_MINOR, VERSION_PATCH)
 VERSION_STR = f"{VERSION_MAJOR}.{VERSION_MINOR}.{VERSION_PATCH}"
@@ -36,3 +36,7 @@ MAX_THREAD_NB = 8  # Max number of threads
 # name is the filename, without extension ("ex" for "ex.bib")
 # suffix is the file extansion, with leading dot (".bib" for "ex.bib")
 BTAC_FILENAME = "{name}.btac{suffix}"
+
+# Most APIs allow to limit the number of results returned for a search query
+# This allows for smaller data transfers
+QUERY_MAX_RESULTS = 3
